package net.zenrindatacom.geofenceapp_sample.activity.area;

import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;

import net.zenrindatacom.geofenceapp_sample.R;
import net.zenrindatacom.geofenceapp_sample.activity.EdgeToEdgeCompatActivity;
import net.zenrindatacom.geofenceapp_sample.activity.general.CustomAsyncTask;
import net.zenrindatacom.geofenceapp_sample.activity.general.DialogUtil;
import net.zenrindatacom.geofenceapp_sample.geofence.GeoFenceWrapperManager;
import net.zenrindatacom.geofencelib.GeoFenceManager;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * エリア情報追加画面
 */
public class AreaInformationAddActivity extends EdgeToEdgeCompatActivity {

    /** 入力フィールド：エリアID */
    private EditText mEditTextAid;
    /** 入力フィールド：ポリゴン情報 */
    private EditText mEditTextPinf;
    /** 入力フィールド：緯度 */
    private EditText mEditTextLat;
    /** 入力フィールド：経度 */
    private EditText mEditTextLon;
    /** 入力フィールド：半径 */
    private EditText mEditTextRad;
    /** 入力フィールド：IN精度閾値 */
    private EditText mEditTextInlv;
    /** 入力フィールド：IN確定回数閾値 */
    private EditText mEditTextInfnum;
    /** 入力フィールド：OUT精度閾値 */
    private EditText mEditTextOutlv;
    /** 入力フィールド：OUT確定回数閾値 */
    private EditText mEditTextOutfnum;
    /** 入力フィールド：有効期間（開始）*/
    private EditText mEditTextVst;
    /** 入力フィールド：有効期間（終了）*/
    private EditText mEditTextVet;

    /**
     * onCreate
     */
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.area_information_add);
        findView();
    }

    /**
     * 画面リソースの展開
     */
    private void findView() {
        mEditTextAid = findViewById(R.id.editTextAID_area);
        mEditTextPinf = findViewById(R.id.editTextPinf);
        mEditTextLat = findViewById(R.id.editTextLat);
        mEditTextLon = findViewById(R.id.editTextLon);
        mEditTextRad = findViewById(R.id.editTextRad);
        mEditTextInlv = findViewById(R.id.editTextInlv);
        mEditTextInfnum = findViewById(R.id.editTextInfnum);
        mEditTextOutlv = findViewById(R.id.editTextOutlv);
        mEditTextOutfnum = findViewById(R.id.editTextOutfnum);
        mEditTextVst = findViewById(R.id.editTextVst);
        mEditTextVet = findViewById(R.id.editTextVet);
    }

    /**
     * 画面内のボタンがタップされた
     *
     * @param view タップされたアイテム
     */
    public void onClick(View view) {

        //2度押し防止
        Button button = (Button)view;
        button.setEnabled(false);
        new Handler(Looper.getMainLooper()).postDelayed(() -> button.setEnabled(true), 1000);

        if (view.getId() == R.id.btnAddAreaInformation) {
            //追加
            addArea();
        }
    }

    /**
     * ジオフェンスライブラリへ「エリア情報」を追加する
     */
    private void addArea() {

        HashMap<String, Object> information = new HashMap<>();

        //エリアID
        if (mEditTextAid.length() > 0) {
            information.put(GeoFenceManager.RESPONSE_KEY_AID, mEditTextAid.getText().toString());
        }

        //ポリゴン
        if (mEditTextPinf.length() > 0) {
            information.put(GeoFenceManager.RESPONSE_KEY_PINF, mEditTextPinf.getText().toString());
        }

        //緯度
        if (mEditTextLat.length() > 0) {
            double parseValue;
            try {
                parseValue = Double.parseDouble(mEditTextLat.getText().toString());
            } catch (NumberFormatException ex) {
                DialogUtil.showAlert(this, R.string.dlg_msg_alert_latitude_format_error);
                return;
            }
            information.put(GeoFenceManager.RESPONSE_KEY_LAT, parseValue);
        }

        //経度
        if (mEditTextLon.length() > 0) {
            double parseValue;
            try {
                parseValue = Double.parseDouble(mEditTextLon.getText().toString());
            } catch(NumberFormatException ex) {
                DialogUtil.showAlert(this, R.string.dlg_msg_alert_longitude_format_error);
                return;
            }
            information.put(GeoFenceManager.RESPONSE_KEY_LON, parseValue);
        }

        //半径
        if (mEditTextRad.length() > 0) {
            int parseValue;
            try {
                parseValue = Integer.parseInt(mEditTextRad.getText().toString());
            } catch(NumberFormatException ex) {
                DialogUtil.showAlert(this, R.string.dlg_msg_alert_radius_format_error);
                return;
            }
            information.put(GeoFenceManager.RESPONSE_KEY_RAD, parseValue);
        }

        //IN精度閾値
        if (mEditTextInlv.length() > 0) {
            int parseValue;
            try {
                parseValue = Integer.parseInt(mEditTextInlv.getText().toString());
            } catch(NumberFormatException ex) {
                DialogUtil.showAlert(this, R.string.dlg_msg_alert_in_level_format_error);
                return;
            }
            information.put(GeoFenceManager.RESPONSE_KEY_INLV, parseValue);
        }

        //IN確定回数閾値
        if (mEditTextInfnum.length() > 0) {
            int parseValue;
            try {
                parseValue = Integer.parseInt(mEditTextInfnum.getText().toString());
            } catch(NumberFormatException ex) {
                DialogUtil.showAlert(this, R.string.dlg_msg_alert_in_f_number_format_error);
                return;
            }
            information.put(GeoFenceManager.RESPONSE_KEY_INFNUM, parseValue);
        }

        //OUT精度閾値
        if (mEditTextOutlv.length() > 0) {
            int parseValue;
            try {
                parseValue = Integer.parseInt(mEditTextOutlv.getText().toString());
            } catch(NumberFormatException ex) {
                DialogUtil.showAlert(this, R.string.dlg_msg_alert_out_level_format_error);
                return;
            }
            information.put(GeoFenceManager.RESPONSE_KEY_OUTLV, parseValue);
        }

        //OUT確定回数閾値
        if (mEditTextOutfnum.length() > 0) {
            int parseValue;
            try {
                parseValue = Integer.parseInt(mEditTextOutfnum.getText().toString());
            } catch(NumberFormatException ex) {
                DialogUtil.showAlert(this, R.string.dlg_msg_alert_out_f_number_format_error);
                return;
            }
            information.put(GeoFenceManager.RESPONSE_KEY_OUTFNUM, parseValue);
        }

        //有効期間（開始）
        if (mEditTextVst.length() > 0) {
            information.put(GeoFenceManager.RESPONSE_KEY_VST, mEditTextVst.getText().toString());
        }

        //有効期間（終了）
        if (mEditTextVet.length() > 0) {
            information.put(GeoFenceManager.RESPONSE_KEY_VET, mEditTextVet.getText().toString());
        }

        //1つ以上の項目が入力されているか？
        if (information.size() == 0) {
            DialogUtil.showAlert(this, R.string.dlg_msg_alert_no_entry);
            return;
        }

        ArrayList<HashMap<String, Object>> informationList = new ArrayList<>();
        informationList.add(information);

        // プログレスバーを表示
        DialogUtil.showProgress(getSupportFragmentManager(), R.string.dlg_msg_progress_add);

        new CustomAsyncTask() {
            @Override
            public Object doAsyncTask() {
                //ジオフェンスライブラリにエリアを追加
                return GeoFenceWrapperManager.getGeoFenceManager().addAreaInformation(informationList);
            }

            @Override
            public void onSuccess(Object result) {
                // プログレスバーを消す
                DialogUtil.hideProgress();

                if (result == null || ((List<?>)result).size() > 0) {
                    //追加失敗
                    DialogUtil.showAlert(AreaInformationAddActivity.this, R.string.dlg_title_alert_geofence_lib, R.string.dlg_msg_alert_geofence_lib_add_fail);
                } else {
                    //追加成功
                    DialogUtil.showAlert(AreaInformationAddActivity.this, R.string.dlg_title_alert_geofence_lib, R.string.dlg_msg_alert_geofence_lib_add_success);
                }
            }

            @Override
            public void onException(Exception e) {
            }
        }.execute();
    }
}
