package net.zenrindatacom.geofenceapp_sample.activity.area;

import android.app.AlertDialog;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;

import net.zenrindatacom.geofenceapp_sample.activity.EdgeToEdgeCompatActivity;
import net.zenrindatacom.geofenceapp_sample.activity.general.CustomAsyncTask;
import net.zenrindatacom.geofenceapp_sample.activity.general.DialogUtil;
import net.zenrindatacom.geofenceapp_sample.R;
import net.zenrindatacom.geofenceapp_sample.geofence.GeoFenceWrapperManager;

import java.util.ArrayList;
import java.util.List;

/**
 * エリア情報管理画面
 */
public class AreaInformationMngActivity extends EdgeToEdgeCompatActivity {

    /** ログのTAG */
    private static final String TAG = "AreaInformationMngActivity";

    /**
     * onCreate
     */
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.area_information_mng);
    }

    /**
     * 画面内のボタンがタップされた
     *
     * @param view タップされたアイテム
     */
    public void onClick(View view) {

        //2度押し防止
        Button button = (Button)view;
        button.setEnabled(false);
        new Handler(Looper.getMainLooper()).postDelayed(() -> button.setEnabled(true), 1000);

        int viewId = view.getId();

        if(viewId == R.id.btnAddAreaInformation) {
            //エリア情報を追加
            Intent intent = new Intent(this, AreaInformationAddActivity.class);
            startActivity(intent);

        } else if(viewId == R.id.btnDeleteAreaInformation) {
            //エリア情報を削除
            removeAreaInformation();

        } else if(viewId == R.id.btnGetAreaInformation) {
            //エリア情報を取得
            getAreaInformationList();
        }
    }

    /**
     * エリア情報を削除
     */
    private void removeAreaInformation() {

        //エリアIDの入力フィールド
        final EditText editTextAreaId = new EditText(this);

        //確認ダイアログの表示
        new AlertDialog.Builder(this)
                .setIcon(android.R.drawable.ic_dialog_info)
                .setTitle(R.string.dlg_title_confirm_delete_area_information)
                .setMessage(R.string.dlg_msg_confirm_delete_area_information)
                .setView(editTextAreaId)
                .setPositiveButton(R.string.dlg_btn_ok, (dialog, whichButton) -> {
                    //OKボタンをタップ

                    String inputAreaId = editTextAreaId.getText().toString();
                    Log.d(TAG, "Input Area Id=" + inputAreaId);

                    ArrayList<String> inputAreaIdList = new ArrayList<>();
                    if (inputAreaId.length() > 0) {
                        inputAreaIdList.add(inputAreaId);
                    }

                    // プログレスバーを表示
                    DialogUtil.showProgress(getSupportFragmentManager(), R.string.dlg_msg_progress_remove);

                    new CustomAsyncTask() {
                        @Override
                        public List<String> doAsyncTask() {
                            //ジオフェンスライブラリからエリア情報を削除する
                            return GeoFenceWrapperManager.getGeoFenceManager().removeAreaInformation(inputAreaIdList);
                        }

                        @Override
                        public void onSuccess(Object result) {
                            // プログレスバーを消す
                            DialogUtil.hideProgress();

                            if (result != null && ((List<?>)result).size() > 0) {
                                //削除したものが存在する
                                DialogUtil.showAlert(AreaInformationMngActivity.this, R.string.dlg_title_alert_geofence_lib, R.string.dlg_msg_alert_geofence_lib_delete_success);
                            } else {
                                //削除したものが存在しない
                                DialogUtil.showAlert(AreaInformationMngActivity.this, R.string.dlg_title_alert_geofence_lib, R.string.dlg_msg_alert_geofence_lib_delete_fail);
                            }
                        }

                        @Override
                        public void onException(Exception e) {
                        }
                    }.execute();

                })
                .setNegativeButton(R.string.dlg_btn_cancel, null)
                .show();
    }

    /**
     * エリア情報を取得
     */
    private void getAreaInformationList() {

        //エリアIDの入力フィールド
        final EditText editTextAreaId = new EditText(this);

        //確認ダイアログの表示
        new AlertDialog.Builder(this)
                .setIcon(android.R.drawable.ic_dialog_info)
                .setTitle(R.string.dlg_title_confirm_get_area_information)
                .setMessage(R.string.dlg_msg_confirm_get_area_information)
                .setView(editTextAreaId)
                .setPositiveButton(R.string.dlg_btn_ok, (dialog, whichButton) -> {
                    //OKボタンをタップ

                    //エリア情報が存在する場合は「エリア情報表示画面」に表示
                    Intent intent = new Intent(this, AreaInformationListActivity.class);
                    //表示データ
                    String inputAreaId = editTextAreaId.getText().toString();
                    Log.d(TAG, "Input Area Id=" + inputAreaId);
                    intent.putExtra(AreaInformationListActivity.INTENT_KEY_CONDITION, inputAreaId);

                    startActivity(intent);
                })
                .setNegativeButton(R.string.dlg_btn_cancel, null)
                .show();
    }
}
